@@ -6,7 +6,7 @@ def send_contact_form_email(sender, request, form, **kwargs):
     """sends the email from the contact form"""
     data = form.cleaned_data
     # render the template
-    w = loader.get_template('cccontact/message.txt')
+    t = loader.get_template('cccontact/message.txt')
     c = Context({
         'message': data.get('m'),
         'phone': data.get('phone')})
